summaryrefslogtreecommitdiff
path: root/file.h
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2013-04-01 20:36:42 +0000
committerGuy Harris <guy@alum.mit.edu>2013-04-01 20:36:42 +0000
commit82a602d697b03314a11b3fd914dc7173fe18b293 (patch)
tree85adc187849d0ebcbcc2997db1edfab1ab15fd2f /file.h
parent2deedfb1e1288e79341bf05704f0662c251897e7 (diff)
downloadwireshark-82a602d697b03314a11b3fd914dc7173fe18b293.tar.gz
Define a collection of bits for different types of capture file comments.
For each capture file type, have a bitset of comment types supported by that capture file type. Add a Wiretap routine that, for a given file type, returns the bitset of comment types it supports. Have wtap_get_savable_file_types() take a bitset of comment types that need to be supported by the file types it returns. Replace cf_has_comments() with a routine that returns a bitset of capture file comment types in the capture file. Use those routines in the capture file dialogs; don't wire in the notion that pcap-NG supports all comment types and no other file formats support any comment types. (That's currently true, but we don't want to wire that in as being forever true.) svn path=/trunk/; revision=48689
Diffstat (limited to 'file.h')
-rw-r--r--file.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/file.h b/file.h
index 403449aeea..ae9fb8cc00 100644
--- a/file.h
+++ b/file.h
@@ -652,12 +652,12 @@ void cf_update_capture_comment(capture_file *cf, gchar *comment);
void cf_update_packet_comment(capture_file *cf, frame_data *fdata, gchar *comment);
/**
* Does this capture file have any comments?
*
* @param cf the capture file
- * @return TRUE if it does, FALSE if it doesn't
+ * @return bitset of WTAP_COMMENT_ values
*/
-gboolean cf_has_comments(capture_file *cf);
+guint32 cf_comment_types(capture_file *cf);
#if defined(HAVE_HEIMDAL_KERBEROS) || defined(HAVE_MIT_KERBEROS)
WS_DLL_PUBLIC
@@ -652,12 +652,12 @@ void cf_update_capture_comment(capture_file *cf, gchar *comment);
void cf_update_packet_comment(capture_file *cf, frame_data *fdata, gchar *comment);
/**
- * Does this capture file have any comments?
+ * What types of comments does this file have?
*
* @param cf the capture file